Bifrost: Data Fields

Bifrost

Here is a list of all documented struct and union fields with links to the struct/union documentation for each field:

### - s -

- searchSequence() : CompactedDBG< Unitig_data_t, Graph_data_t >
- selfForwardBase() : Kmer
- serialize() : CCDBG_Data_t< Unitig_data_t > , CDBG_Data_t< Unitig_data_t, Graph_data_t > , DataAccessor< Unitig_data_t >
- set_deleted() : Kmer
- set_empty() : Kmer
- set_k() : Kmer
- setChar() : Kmer
- simplify() : CompactedDBG< Unitig_data_t, Graph_data_t >
- size() : CompactedDBG< Unitig_data_t, Graph_data_t > , UnitigColors , UnitigMapBase
- strand : UnitigMapBase